@@ -1,7 +1,8 @@
 use crate::model::error_proto::ErrorProto;
 use serde::{Deserialize, Serialize};
+use std::fmt::{Display, Formatter};
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct TableDataInsertAllResponseInsertErrors {
     /// Error information for the row indicated by the index property.
@@ -11,3 +12,9 @@ pub struct TableDataInsertAllResponseInsertErrors {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub index: Option<i32>,
 }
+
+impl Display for TableDataInsertAllResponseInsertErrors {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        f.write_str(&format!("{:?}", self))
+    }
+}
